diff lisp/man.el @ 32396:b68d86c19284

(Man-getpage-in-background): Fix previous change. Decode the process output only when we are in multibyte mode.
author Kenichi Handa <handa@m17n.org>
date Wed, 11 Oct 2000 23:59:16 +0000
parents 70fe74e07912
children b5e119e4bfcb
line wrap: on
line diff
--- a/lisp/man.el	Wed Oct 11 23:56:30 2000 +0000
+++ b/lisp/man.el	Wed Oct 11 23:59:16 2000 +0000
@@ -592,8 +592,10 @@
 	    ;; But don't prevent decoding of the outside.
 	    (coding-system-for-write 'raw-text-unix)
 	    ;; We must decode the output by a coding system that the
-	    ;; systen locale suggests.
-	    (coding-system-for-read locale-coding-system)
+	    ;; systen locale suggests in multibyte mode.
+	    (coding-system-for-read
+	     (if default-enable-multibyte-characters
+		 locale-coding-system 'raw-text-unix))
 	    ;; Avoid possible error by using a directory that always exists.
 	    (default-directory "/"))
 	;; Prevent any attempt to use display terminal fanciness.